@@ -203,7 +203,9 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
         await self.playwright_context_manager.__aexit__()
 
     def download_request(self, request: Request, spider: Spider) -> Deferred:
-        return deferred_from_coro(self._download_request(request, spider))
+        if request.meta.get("playwright"):
+            return deferred_from_coro(self._download_request(request, spider))
+        return super().download_request(request, spider)
 
     async def _download_request(self, request: Request, spider: Spider) -> Response:
         page = None
